@@ -11,7 +11,7 @@ use Exporter qw(import);
  
 our @EXPORT_OK = qw(convert get_units);
 
-our $VERSION = '0.027';
+our $VERSION = '0.028';
 
 sub new {
     my $class = shift;
@@ -1031,6 +1031,12 @@ sub get_units {
             'factor'    => 15500031,
             'aliases'   => ['square inches', 'inch^2','inches^2', 'squinch', 'in^2', 'in'],
             'type'      => 'area',
+        },
+        {
+            'unit'      => 'tsubo',
+            'factor'    => 3024.9863876,
+            'aliases'   => ['tsubos'],
+            'type'      => 'area',
         }
     );
 
@@ -1141,7 +1147,7 @@ Convert::Pluggable - convert between various units of measurement
 
 =head1 VERSION
 
-Version 0.027
+Version 0.028
 
 =head1 SYNOPSIS
 
